
c/* %W%      latest revision %G% %U% */
      subroutine MIXUPN (bn, bnf, t, tx)
************************************************************************

c *** Forms the partial wave decomposition of p-N amplitudes

c *** Code for bn, bnf, bnuc, bnucf
c        1 ReSp    2 ImSp   3 ReSn   4 ImSn
c        5 RePp    6 ImPp   7 RePn   8 ImPn
c        9 ReDp   10 ImDp  11 ReDn  12 ImDn
c       13 ReFp   14 ImFp  15 ReFn  16 ImFn
c       17 ReGp   18 ImGp  19 ReGn  20 ImGn
c       21 ReHp   22 ImHp  23 ReHn  24 ImHn
c       25 ReIp   26 ImIp  27 ReIn  28 ImIn
c       29 ReJp   30 ImJp  31 ReJn  32 ImJn
c       33 ReKp   34 ImKp  35 ReKn  36 ImKn

c *** See eq. 211 in Goldberger & Watson for alphas and gammas
c     pg. 394 and pg. 397 for t's (note difference in sign)
c     when protons are incident

c ***

      implicit real*8 (a-h, o-z)

      dimension bn(40), bnf(40), t(40), tx(40)

c >>> FIRST EXECUTABLE STATEMENT <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

      bn(1)  = t(1)
      bn(2)  = tx(1)
      bn(3)  = 0.5 * ( t(13)  + 3.*t(17)  )
      bn(4)  = 0.5 * ( tx(13) + 3.*tx(17) )
      bn(5)  = 5.*t(6)  + 3.*t(5)  + t(4)
      bn(6)  = 5.*tx(6) + 3.*tx(5) + tx(4)
      bn(7)  = 0.5 * ( bn(5) + 3.*t(14)  )
      bn(8)  = 0.5 * ( bn(6) + 3.*tx(14) )
      bn(9)  = 5.*t(2)
      bn(10) = 5.*tx(2)
      bn(11) = 0.5 * ( bn(9)  + 7.*t(20)  + 5.*t(19)  + 3.*t(18)  )
      bn(12) = 0.5 * ( bn(10) + 7.*tx(20) + 5.*tx(19) + 3.*tx(18) )
      bn(13) = 9.*t(9)  + 7.*t(8)  + 5.*t(7)
      bn(14) = 9.*tx(9) + 7.*tx(8) + 5.*tx(7)
      bn(15) = 0.5 * ( bn(13) + 7.*t(15)  )
      bn(16) = 0.5 * ( bn(14) + 7.*tx(15) )
      bn(17) = 9.*t(3)
      bn(18) = 9.*tx(3)
      bn(19) = 0.5 * ( bn(17) + 11.*t(23)  + 9.*t(22)  + 7.*t(21)  )
      bn(20) = 0.5 * ( bn(18) + 11.*tx(23) + 9.*tx(22) + 7.*tx(21) )
      bn(21) = 13.*t(12)  + 11.*t(11)  + 9.*t(10)
      bn(22) = 13.*tx(12) + 11.*tx(11) + 9.*tx(10)
      bn(23) = 0.5 * ( bn(21) + 11.*t(16)  )
      bn(24) = 0.5 * ( bn(22) + 11.*tx(16) )
      bn(25) = 13.*t(24)
      bn(26) = 13.*tx(24)
      bn(27) = 0.5 * (13.*t(28)  + 11.*t(27)  + 13.*t(24)  + 15.*t(29) )
      bn(28) = 0.5 * (13.*tx(28) + 11.*tx(27) + 13.*tx(24) + 15.*tx(29))
      bn(29) = 15.*t(26)  + 13.*t(25)
      bn(30) = 15.*tx(26) + 13.*tx(25)
      bn(31) = 0.5 * ( 15.*t(26)  + 13.*t(25)  + 15.*t(30)  )
      bn(32) = 0.5 * ( 15.*tx(26) + 13.*tx(25) + 15.*tx(30) )
      bn(33) = 0.
      bn(34) = 0.
      bn(35) = 0.5 * ( 17.*t(32)  + 15.*t(31)  )
      bn(36) = 0.5 * ( 17.*tx(32) + 15.*tx(31) )

c *** SPIN FLIP

      bnf(1)  = 0.
      bnf(2)  = 0.
      bnf(3)  = 1.5*t(17)
      bnf(4)  = 1.5*tx(17)
      bnf(5)  = 2.5*t(6)  - 1.5*t(5)  - t(4)
      bnf(6)  = 2.5*tx(6) - 1.5*tx(5) - tx(4)
      bnf(7)  = 0.5 * bnf(5)
      bnf(8)  = 0.5 * bnf(6)
      bnf(9)  = 0.
      bnf(10) = 0.
      bnf(11) = 0.5 * ( 7./3.*t(20)  - 5./6.*t(19)  - 1.5*t(18)  )
      bnf(12) = 0.5 * ( 7./3.*tx(20) - 5./6.*tx(19) - 1.5*tx(18) )
      bnf(13) = 2.25*t(9)  - 7./12.*t(8)  - 5./3.*t(7)
      bnf(14) = 2.25*tx(9) - 7./12.*tx(8) - 5./3.*tx(7)
      bnf(15) = 0.5 * bnf(13)
      bnf(16) = 0.5 * bnf(14)
      bnf(17) = 0.
      bnf(18) = 0.
      bnf(19) = 0.5 * ( 2.2*t(23)  - 0.45*t(22)  - 1.75*t(21)  )
      bnf(20) = 0.5 * ( 2.2*tx(23) - 0.45*tx(22) - 1.75*tx(21) )
      bnf(21) = 13./6.*t(12)  - 11./30.*t(11)  - 1.8*t(10)
      bnf(22) = 13./6.*tx(12) - 11./30.*tx(11) - 1.8*tx(10)
      bnf(23) = 0.5 * bnf(21)
      bnf(24) = 0.5 * bnf(22)
      bnf(25) = 0.
      bnf(26) = 0.
      bnf(27) = 0.5 * ( 15./7.*t(29)  - 11./6.*t(27)  - 13./42.*t(28)  )
      bnf(28) = 0.5 * ( 15./7.*tx(29) - 11./6.*tx(27) - 13./42.*tx(28) )
      bnf(29) = -13./7.*t(25)  - 15./56.*t(26)
      bnf(30) = -13./7.*tx(25) - 15./56.*tx(26)
      bnf(31) = 0.5 * bnf(29)
      bnf(32) = 0.5 * bnf(30)
      bnf(33) = 0.
      bnf(34) = 0.
      bnf(35) = 0.5 * ( -15./8.*t(31)  - 17./72.*t(32)  )
      bnf(36) = 0.5 * ( -15./8.*tx(31) - 17./72.*tx(32) )

c *** Correction for elementary amplitudes
c *** a factor of 1/2 included in imwave, rewave in TNCM

      return
      end
