      subroutine TSPIN (t1m1, t11, t00, t01, t10, tss, t, tx, ta, tax)
************************************************************************

c *** Computes t1-1, t11, t00, tss page 397 of Goldberger & Watson.
c *** See also Stapp, Ypsilantis, and Metropolis Phys Rev 105 #1,305,/57

c *** Code for all ts
c      1 res p   2 ims p  3 res n  4 ims n
c      5 rep p   6 imp p  7 rep n  8 imp n
c      9 red p  10 imd p 11 red n 12 imd n
c     13 ref p  14 imf p 15 ref n 16 imf n
c     17 reg p  18 img p 19 reg n 20 img n
c     21 reh p  22 imh p 23 reh n 24 imh n
c     25 rei p  26 imi p 27 rei n 28 imi n
c     29 rej p  30 imj p 31 rej n 32 imj n
c     33 rek p  34 imk p 35 rek n 36 imk n

c *** Note a factor of 1/2 not included in t11, t00, tss, t1m1, t01, t10
c     not included because was included in TNCM in rewave and imwave

c *** REVISION HISTORY ***
c        2/18/88 (M.S.)  included calculation of t01 and t10
c
c        3/11/88 (M.S.)  Removed t(13) amplitude from calculation
c                        of t11(3) as this is the 1S0 partial wave
c                        and should not occur in t11(3)

      implicit real*8 (a-h, o-z)

      character*80 SCCSID

      dimension t1m1(40),t11(40),t00(40),tss(40), t01(40), t10(40)
CCC	Added for off-diagonal component (pjd 4/4/93)
CCC		(note that ta(i) represents l-1,l+1 
CCC		           ta(i+7)          l+1,l-1   etc.)	
CCC	All changes to t values will be preceded by CCC and original line
      dimension t(40), tx(40), ta(14), tax(14)
c      dimension t(40), tx(40), ta(7), tax(7)
CCC

c*******************************************************************************

      sr2  = DSQRT( 2.d0 )
      sr6  = DSQRT( 6.d0 )
      sr12 = DSQRT(12.d0)
      sr30 = DSQRT(30.d0)
      sr20 = DSQRT(20.d0)
      sr42 = DSQRT(42.d0)
      sr56 = DSQRT(56.d0)
      sr72 = DSQRT(72.d0)

c *** A factor of 2 for protons included as in
c *** Stapp, Ypsilantis, and Metropolis.  A factor of one half not included
c *** because was included in rewave, and imwave in TNCM
c *** a factor of 2 also included
c *** for neutrons according to Mcgregor, Moravcsik, and Stapp
c *** Ann Rev Nucl Sci p312, 1960

      tss(1)  =  2.*t(1)
      tss(2)  =  2.*tx(1)
      tss(3)  =  0.5*tss(1)
      tss(4)  =  0.5*tss(2)
      tss(5)  =  0.0
      tss(6)  =  0.0
      tss(7)  =  3.*t(14)
      tss(8)  =  3.*tx(14)
      tss(9)  = 10.*t(2)
      tss(10) = 10.*tx(2)
      tss(11) =  0.5*tss(9)
      tss(12) =  0.5*tss(10)
      tss(13) =  0.0
      tss(14) =  0.0
      tss(15) =  7.*t(15)
      tss(16) =  7.*tx(15)
      tss(17) = 18.*t(3)
      tss(18) = 18.*tx(3)
      tss(19) =  0.5*tss(17)
      tss(20) =  0.5*tss(18)
      tss(21) =  0.0
      tss(22) =  0.0
      tss(23) = 11.*t(16)
      tss(24) = 11.*tx(16)
      tss(25) = 26.*t(24)
      tss(26) = 26.*tx(24)
      tss(27) =  0.5*tss(25)
      tss(28) =  0.5*tss(26)
      tss(29) =  0.0
      tss(30) =  0.0
      tss(31) = 15.*t(30)
      tss(32) = 15.*tx(30)
      tss(33) =  0.0
      tss(34) =  0.0
      tss(35) =  0.0
      tss(36) =  0.0

c *** For t11 for protons only odd l's contribute then
c *** for even l t11 and t1-1 are taken as zero but not
c *** for neutrons

      t11(1)  =  0.0
      t11(2)  =  0.0
      t11(3)  =  0.5 * ( 2.*t(17) - sr2*ta(1) )
      t11(4)  =  0.5 * ( 2.*tx(17) - sr2*tax(1) )
      t11(5)  =  3.*t(6)  + 3.*t(5)  - sr6*ta(2)
      t11(6)  =  3.*tx(6) + 3.*tx(5) - sr6*tax(2)
      t11(7)  =  0.5*t11(5)
      t11(8)  =  0.5*t11(6)
      t11(9)  =  0.0
      t11(10) =  0.0
      t11(11) =  0.5 * (4.*t(20) + 5.*t(19) + t(18) - sr12*ta(3)
CCC  $                                              - sr2*ta(1)  )
     $                                              - sr2*ta(8)  )
      t11(12) =  0.5 * (4.*tx(20) + 5.*tx(19) + tx(18) - sr12*tax(3)
CCC  $                                                 - sr2*tax(1)  )
     $                                                 - sr2*tax(8)  )
CCC   t11(13) = 5.*t(9) + 7.*t(8) + 2.*t(7) - sr20*ta(4) - sr6*ta(2)
      t11(13) = 5.*t(9) + 7.*t(8) + 2.*t(7) - sr20*ta(4) - sr6*ta(9)
      t11(14) = 5.*tx(9) + 7.*tx(8) + 2.*tx(7) - sr20*tax(4)
CCC  $                                         - sr6*tax(2)
     $                                         - sr6*tax(9)
      t11(15) = 0.5*t11(13)
      t11(16) = 0.5*t11(14)
      t11(17) = 0.0
      t11(18) = 0.0
      t11(19) = 0.5 * (6.*t(23) + 9.*t(22) + 3.*t(21) - sr30*ta(5)
CCC  $                                                - sr12*ta(3) )
     $                                                - sr12*ta(10) )
      t11(20) = 0.5 * (6.*tx(23) + 9.*tx(22) + 3.*tx(21) - sr30*tax(5)
CCC  $                                                   - sr12*tax(3) )
     $                                                   - sr12*tax(10))
      t11(21) = 7.*t(12) + 11.*t(11) + 4.*t(10)
CCC  $                               - sr42*ta(6) - sr20*ta(4)
     $                               - sr42*ta(6) - sr20*ta(11)
      t11(22) = 7.*tx(12) + 11.*tx(11) + 4.*tx(10)
CCC  $                                 - sr42*tax(6) - sr20*tax(4)
     $                                 - sr42*tax(6) - sr20*tax(11)
      t11(23) = 0.5*t11(21)
      t11(24) = 0.5*t11(22)
      t11(25) = 0.0
      t11(26) = 0.0
      t11(27) = 0.5 * (8.*t(29) + 13.*t(28) + 5.*t(27)
CCC  $                                      - sr56*ta(7) - sr30*ta(5) )
     $                                      - sr56*ta(7) - sr30*ta(12))
      t11(28) = 0.5 * (8.*tx(29) + 13.*tx(28) + 5.*tx(27)
CCC  $                           - sr56*tax(7) - sr30*tax(5)  )
     $                           - sr56*tax(7) - sr30*tax(12)  )
CCC   t11(29) = 15.*t(26) + 6.*t(25) - sr42*ta(6)
      t11(29) = 15.*t(26) + 6.*t(25) - sr42*ta(13)
CCC   t11(30) = 15.*tx(26) + 6.*tx(25) - sr42*tax(6)
      t11(30) = 15.*tx(26) + 6.*tx(25) - sr42*tax(13)
      t11(31) =  0.5*t11(29)
      t11(32) =  0.5*t11(30)
      t11(33) =  0.0
      t11(34) =  0.0
CCC   t11(35) =  0.5 * ( 17.*t(32)  + 7.*t(31)  - sr56*ta(7) )
      t11(35) =  0.5 * ( 17.*t(32)  + 7.*t(31)  - sr56*ta(14) )
CCC   t11(36) =  0.5 * ( 17.*tx(32) + 7.*tx(31) - sr56*tax(7) )
      t11(36) =  0.5 * ( 17.*tx(32) + 7.*tx(31) - sr56*tax(14) )

c *** For t00

      t00(1)  =  0.0
      t00(2)  =  0.0
      t00(3)  =  t(17)  + sr2*ta(1)
      t00(4)  =  tx(17) + sr2*tax(1)
      t00(5)  =  2. * ( 2.*t(6)  + t(4)  + sr6*ta(2) )
      t00(6)  =  2. * ( 2.*tx(6) + tx(4) + sr6*tax(2) )
      t00(7)  =  0.5*t00(5)
      t00(8)  =  0.5*t00(6)
      t00(9)  =  0.0
      t00(10) =  0.0
CCC   t00(11) =  3.*t(20)  + 2.*t(18)  + sr12*ta(3)  + sr2*ta(1)
      t00(11) =  3.*t(20)  + 2.*t(18)  + sr12*ta(3)  + sr2*ta(8)
CCC   t00(12) =  3.*tx(20) + 2.*tx(18) + sr12*tax(3) + sr2*tax(1)
      t00(12) =  3.*tx(20) + 2.*tx(18) + sr12*tax(3) + sr2*tax(8)
CCC   t00(13) =  2. * ( 4.*t(9)  + 3.*t(7)  + sr20*ta(4)  + sr6*ta(2) )
      t00(13) =  2. * ( 4.*t(9)  + 3.*t(7)  + sr20*ta(4)  + sr6*ta(9) )
CCC   t00(14) =  2. * ( 4.*tx(9) + 3.*tx(7) + sr20*tax(4) + sr6*tax(2) )
      t00(14) =  2. * ( 4.*tx(9) + 3.*tx(7) + sr20*tax(4) + sr6*tax(9))
      t00(15) =  0.5*t00(13)
      t00(16) =  0.5*t00(14)
      t00(17) =  0.0
      t00(18) =  0.0
CCC   t00(19) =  5.*t(23)  + 4.*t(21)  + sr30*ta(5)  + sr12*ta(3)
      t00(19) =  5.*t(23)  + 4.*t(21)  + sr30*ta(5)  + sr12*ta(10)
CCC   t00(20) =  5.*tx(23) + 4.*tx(21) + sr30*tax(5) + sr12*tax(3)
      t00(20) =  5.*tx(23) + 4.*tx(21) + sr30*tax(5) + sr12*tax(10)
CCC   t00(21) =  2. * ( 6.*t(12) + 5.*t(10) + sr42*ta(6) + sr20*ta(4) )
      t00(21) =  2. * ( 6.*t(12) + 5.*t(10) + sr42*ta(6) + sr20*ta(11))
CCC   t00(22) =  2. *(6.*tx(12) + 5.*tx(10) + sr42*tax(6) + sr20*tax(4))
      t00(22) =  2. *(6.*tx(12) + 5.*tx(10) + sr42*tax(6) +sr20*tax(11))
      t00(23) =  0.5*t00(21)
      t00(24) =  0.5*t00(22)
      t00(25) =  0.0
      t00(26) =  0.0
CCC   t00(27) =  7.*t(29)  + 6.*t(27)  + sr56*ta(7)  + sr30*ta(5)
      t00(27) =  7.*t(29)  + 6.*t(27)  + sr56*ta(7)  + sr30*ta(12)
CCC   t00(28) =  7.*tx(29) + 6.*tx(27) + sr56*tax(7) + sr30*tax(5)
      t00(28) =  7.*tx(29) + 6.*tx(27) + sr56*tax(7) + sr30*tax(12)
CCC   t00(29) =  2. * ( 7.*t(25)  + sr42*ta(6) )
      t00(29) =  2. * ( 7.*t(25)  + sr42*ta(13) )
CCC   t00(30) =  2. * ( 7.*tx(25) + sr42*tax(6) )
      t00(30) =  2. * ( 7.*tx(25) + sr42*tax(13) )
      t00(31) =  0.5*t00(29)
      t00(32) =  0.5*t00(30)
      t00(33) =  0.0
      t00(34) =  0.0
CCC   t00(35) =  8.*t(31)  + sr56*ta(7)
      t00(35) =  8.*t(31)  + sr56*ta(14)
CCC   t00(36) =  8.*tx(31) + sr56*tax(7)
      t00(36) =  8.*tx(31) + sr56*tax(14)

c *** for t01 ***

c     *** S-wave, l = 0 ***

      t01(1) = 0.0
      t01(2) = 0.0
      t01(3) = -sr2*t(17) + ta(1)
      t01(4) = -sr2*tx(17) + tax(1)

c     *** P-wave, l = 1 ***

      t01(5) = sr2*(-3./2.*t(6) + 3./2.*t(5)+dsqrt(3.d0/2.d0)*ta(2))
      t01(6) = sr2*(-3./2.*tx(6) + 3./2.*tx(5)+dsqrt(3.d0/2.d0)*tax(2))
      t01(7) = 0.5*t01(5)
      t01(8) = 0.5*t01(6)

c     *** D-wave, l = 2 ***

      t01(9) = 0.0
      t01(10) = 0.0
      t01(11) = sr2/2.*(-4./3.*t(20) + 5./6.*t(19) + 1./2.*t(18)
CCC  $                   + dsqrt(4.d0/3.d0)*ta(3) - 1./sr2*ta(1))
     $                   + dsqrt(4.d0/3.d0)*ta(3) - 1./sr2*ta(8))
      t01(12) = sr2/2.*(-4./3.*tx(20) + 5./6.*tx(19) + 1./2.*tx(18)
CCC  $                   + dsqrt(4.d0/3.)*tax(3) - 1./sr2*tax(1))
     $                   + dsqrt(4.d0/3.)*tax(3) - 1./sr2*tax(8))

c     *** F-wave, l = 3 ***

      t01(13) = sr2*(-5./4.*t(9) + 7./12.*t(8) + 2./3.*t(7)
CCC  $                + dsqrt(5.d0/4.)*ta(4) - sqrt(2./3.)*ta(2))
     $                + sqrt(5./4.)*ta(4) - sqrt(2./3.)*ta(9))
      t01(14) = sr2*(-5./4.*tx(9) + 7./12.*tx(8) + 2./3.*tx(7)
CCC  $                + sqrt(5./4.)*tax(4) - sqrt(2./3.)*tax(2))
     $                + sqrt(5./4.)*tax(4) - sqrt(2./3.)*tax(9))
      t01(15) = 0.5 * t01(13)
      t01(16) = 0.5*t01(14)

c     *** G-wave, l = 4 ***

      t01(17) = 0.0
      t01(18) = 0.0
      t01(19) = sr2/2.*(-6./5.*t(23) + 9./20.*t(22) + 3./4.*t(21)
CCC  $                   + sqrt(6./5.)*ta(5) - sqrt(3./4.)*ta(3))
     $                   + sqrt(6./5.)*ta(5) - sqrt(3./4.)*ta(10))
      t01(20) = sr2/2.*(-6./5.*tx(23) + 9./20.*tx(22) + 3./4.*tx(21)
CCC  $                   + sqrt(6./5.)*tax(5) - sqrt(3./4.)*tax(3))
     $                   + sqrt(6./5.)*tax(5) - sqrt(3./4.)*tax(10))

c     *** H-wave, l = 5 ***

      t01(21) = sr2*(-7./6.*t(12) + 11./30.*t(11) + 4./5.*t(10)
CCC  $                + sqrt(7./6.)*ta(6) - sqrt(4./5.)*ta(4))
     $                + sqrt(7./6.)*ta(6) - sqrt(4./5.)*ta(11))
      t01(22) = sr2*(-7./6.*tx(12) + 11./30.*tx(11) + 4./5.*tx(10)
CCC  $                + sqrt(7./6.)*tax(6) - sqrt(4./5.)*tax(4))
     $                + sqrt(7./6.)*tax(6) - sqrt(4./5.)*tax(11))
      t01(23) = 0.5 * t01(21)
      t01(24) = 0.5 * t01(22)

c     *** I-wave, l = 6 ***

      t01(25) = 0.0
      t01(26) = 0.0
      t01(27) = sr2/2.*(-8./7.*t(29) + 13./42.*t(28) + 5./6.*t(27)
CCC  $                   + sqrt(8./7.)*ta(7) - sqrt(5./6.)*ta(5))
     $                   + sqrt(8./7.)*ta(7) - sqrt(5./6.)*ta(12))
      t01(28) = sr2/2.*(-8./7.*tx(29) + 13./42.*tx(28) + 5./6.*tx(27)
CCC  $                   + sqrt(8./7.)*tax(7) - sqrt(5./6.)*tax(5))
     $                   + sqrt(8./7.)*tax(7) - sqrt(5./6.)*tax(12))

c     *** J-wave, l = 7 ***

CCC   t01(29) = sr2*(15./56.*t(26) + 6./7.*t(25) - sqrt(6./7.)*ta(6))
      t01(29) = sr2*(15./56.*t(26) + 6./7.*t(25) -sqrt(6./7.)*ta(13))
CCC   t01(30) = sr2*(15./56.*tx(26) + 6./7.*tx(25) - sqrt(6./7.)*tax(6))
      t01(30) = sr2*(15./56.*tx(26) + 6./7.*tx(25)-sqrt(6./7.)*tax(13))
      t01(31) = 0.5*t01(29)
      t01(32) = 0.5 * t01(30)

c     *** K-wave, l = 8 ***

      t01(33) = 0.0
      t01(34) = 0.0
CCC   t01(35) = sr2/2.*(17./72.*t(32) + 7./8.*t(31) - sqrt(7./8.)*ta(7))
      t01(35) = sr2/2.*(17./72.*t(32) + 7./8.*t(31)-sqrt(7./8.)*ta(14))
      t01(36) = sr2/2.*(17./72.*tx(32) + 7./8.*tx(31)
CCC  $                   - sqrt(7./8.)*tax(7))
     $                   - sqrt(7./8.)*tax(14))

c *** for t10 ***

c     *** S-wave, l = 0 ***

      t10(1) = 0.0
      t10(2) = 0.0
      t10(3) = sr2/2.*(t(17) + sr2*ta(1))
      t10(4) = sr2/2.*(tx(17) + sr2*tax(1))

c     *** P-wave, l = 1 ***

      t10(5) = sr2*(t(6) - t(4) + sqrt(3./2.)*ta(2))
      t10(6) = sr2*(tx(6) - tx(4) + sqrt(3./2.)*tax(2))
      t10(7) = 0.5 * t10(5)
      t10(8) = 0.5 * t10(6)

c     *** D-wave, l = 2 ***

      t10(9) = 0.0
      t10(10) = 0.0
      t10(11) = sr2/2.*(t(20) - t(18)
CCC  $                  + sqrt(4./3.)*ta(3) - sqrt(1./2.)*ta(1))
     $                  + sqrt(4./3.)*ta(3) - sqrt(1./2.)*ta(8))
      t10(12) = sr2/2.*(tx(20) - tx(18)
CCC  $                  + sqrt(4./3.)*tax(3) - sqrt(1./2.)*tax(1))
     $                  + sqrt(4./3.)*tax(3) - sqrt(1./2.)*tax(8))

c     *** F-wave, l = 3 ***

      t10(13) = sr2*(t(9) - t(7)
CCC  $               + sqrt(5./4.)*ta(4) + sqrt(2./3.)*ta(2))
     $               + sqrt(5./4.)*ta(4) + sqrt(2./3.)*ta(9))
      t10(14) = sr2*(tx(9) - tx(7)
CCC  $               + sqrt(5./4.)*tax(4) + sqrt(2./3.)*tax(2))
     $               + sqrt(5./4.)*tax(4) + sqrt(2./3.)*tax(9))
      t10(15) = 0.5 * t10(13)
      t10(16) = 0.5 * t10(14)

c     *** G-wave, l = 4 ***

      t10(17) = 0.0
      t10(18) = 0.0
      t10(19) = sr2/2.*(t(23) - t(21)
CCC  $                  + sqrt(6./5.)*ta(5) - sqrt(3./4.)*ta(3))
     $                  + sqrt(6./5.)*ta(5) - sqrt(3./4.)*ta(10))
      t10(20) = sr2/2.*(tx(23) - tx(21)
CCC  $                  + sqrt(6./5.)*tax(5) - sqrt(3./4.)*tax(3))
     $                  + sqrt(6./5.)*tax(5) - sqrt(3./4.)*tax(10))

c     *** H-wave, l = 5 ***

      t10(21) = sr2*(t(12) - t(10)
CCC  $               + sqrt(7./6.)*ta(6) - sqrt(4./5.)*ta(4))
     $               + sqrt(7./6.)*ta(6) - sqrt(4./5.)*ta(11))
      t10(22) = sr2*(tx(12) - tx(10)
CCC  $               + sqrt(7./6.)*tax(6) - sqrt(4./5.)*tax(4))
     $               + sqrt(7./6.)*tax(6) - sqrt(4./5.)*tax(11))
      t10(23) = 0.5 * t10(21)
      t10(24) = 0.5 * t10(22)

c     *** I-wave, l = 6 ***

      t10(25) = 0.0
      t10(26) = 0.0
      t10(27) = sr2/2.*(t(29) - t(27)
CCC  $                  + sqrt(8./7.)*ta(7) - sqrt(5./6.)*ta(5))
     $                  + sqrt(8./7.)*ta(7) - sqrt(5./6.)*ta(12))
      t10(28) = sr2/2.*(tx(29) - tx(27)
CCC  $                  + sqrt(8./7.)*tax(7) - sqrt(5./6.)*tax(5))
     $                  + sqrt(8./7.)*tax(7) - sqrt(5./6.)*tax(12))

c     *** J-wave, l = 7 ***

CCC   t10(29) = -sr2 * ( t(25) + sqrt(6./7.) * ta(6) )
      t10(29) = -sr2 * ( t(25) + sqrt(6./7.) * ta(13) )
CCC   t10(30) = -sr2 * ( tx(25) + sqrt(6./7.) * tax(6) )
      t10(30) = -sr2 * ( tx(25) + sqrt(6./7.) * tax(13) )
      t10(31) = 0.5 * t10(29)
      t10(32) = 0.5 * t10(30)

c     *** K-wave, l = 8 ***

      t10(33) = 0.0
      t10(34) = 0.0
CCC   t10(35) = -sr2/2. * ( t(31) + sqrt(7./8.) * ta(7) )
      t10(35) = -sr2/2. * ( t(31) + sqrt(7./8.) * ta(14) )
CCC   t10(36) = -sr2/2. * ( tx(31) + sqrt(7./8.) * tax(7) )
      t10(36) = -sr2/2. * ( tx(31) + sqrt(7./8.) * tax(14) )


c *** For t1-1

      t1m1(1)  =  0.0
      t1m1(2)  =  0.0
      t1m1(3)  =  0.5 * ( t(17)  - (1./sr2)*ta(1) )
      t1m1(4)  =  0.5 * ( tx(17) - (1./sr2)*tax(1) )
      t1m1(5)  =  0.5*t(6)  - 1.5*t(5)  + t(4)  - (1./sr6)*ta(2)
      t1m1(6)  =  0.5*tx(6) - 1.5*tx(5) + tx(4) - (1./sr6)*tax(2)
      t1m1(7)  =  0.5*t1m1(5)
      t1m1(8)  =  0.5*t1m1(6)
      t1m1(9)  =  0.0
      t1m1(10) =  0.0
      t1m1(11) =  0.5 * ( (1./3.)*t(20)  - (5./6.)*t(19)  + 0.5*t(18)
CCC  $                     - (1./sr12)*ta(3) - (1./sr2)*ta(1)  )
     $                     - (1./sr12)*ta(3) - (1./sr2)*ta(8)  )
      t1m1(12) =  0.5 * ( (1./3.)*tx(20) - (5./6.)*tx(19) + 0.5*tx(18)
CCC  $                     - (1./sr12)*tax(3) - (1./sr2)*tax(1)  )
     $                     - (1./sr12)*tax(3) - (1./sr2)*tax(8)  )
      t1m1(13) =  0.25*t(9)  - (7./12.)*t(8)  + (1./3.)*t(7)
CCC  $                       - (1./sr20)*ta(4) - (1./sr6)*ta(2)
     $                       - (1./sr20)*ta(4) - (1./sr6)*ta(9)
      t1m1(14) =  0.25*tx(9) - (7./12.)*tx(8) + (1./3.)*tx(7)
CCC  $                       - (1./sr20)*tax(4) - (1./sr6)*tax(2)
     $                       - (1./sr20)*tax(4) - (1./sr6)*tax(9)
      t1m1(15) =  0.5*t1m1(13)
      t1m1(16) =  0.5*t1m1(14)
      t1m1(17) =  0.0
      t1m1(18) =  0.0
      t1m1(19) =  0.5 * ( 0.2*t(23)  - (9./20.)*t(22)  + 0.25*t(21)
CCC  $                    - (1./sr30)*ta(5) - (1./sr12)*ta(3)  )
     $                    - (1./sr30)*ta(5) - (1./sr12)*ta(10)  )
      t1m1(20) =  0.5 * ( 0.2*tx(23) - (9./20.)*tx(22) + 0.25*tx(21)
CCC  $                    - (1./sr30)*tax(5) - (1./sr12)*tax(3)  )
     $                    - (1./sr30)*tax(5) - (1./sr12)*tax(10)  )
      t1m1(21) = (1./6.)*t(12)  - (11./30.) * t(11) + 0.2*t(10)
CCC  $            - (1./sr42)*ta(6) - (1./sr20)*ta(4)
     $            - (1./sr42)*ta(6) - (1./sr20)*ta(11)
      t1m1(22) = (1./6.)*tx(12) - (11./30.)*tx(11) + 0.2*tx(10)
CCC  $            - (1./sr42)*tax(6) - (1./sr20)*tax(4)
     $            - (1./sr42)*tax(6) - (1./sr20)*tax(11)
      t1m1(23) =  0.5*t1m1(21)
      t1m1(24) =  0.5*t1m1(22)
      t1m1(25) =  0.0
      t1m1(26) =  0.0
      t1m1(27) =  0.5 * ((1./7.)*t(29) - (13./42.)*t(28) + (1./6.)*t(27)
CCC  $                   - (1./sr56)*ta(7) - (1./sr30)*ta(5) )
     $                   - (1./sr56)*ta(7) - (1./sr30)*ta(12) )
      t1m1(28) =  0.5 * ( (1./7.)*tx(29) - (13./42.)*tx(28)
     $                     + (1./6.)*tx(27) - (1./sr56)*tax(7)
CCC  $                     - (1./sr30)*tax(5) )
     $                     - (1./sr30)*tax(12) )
CCC   t1m1(29) = -(15./56.)*t(26)  + (1./7.)*t(25)  - (1./sr42)*ta(6)
      t1m1(29) = -(15./56.)*t(26)  + (1./7.)*t(25)  - (1./sr42)*ta(13)
CCC   t1m1(30) = -(15./56.)*tx(26) + (1./7.)*tx(25) - (1./sr42)*tax(6)
      t1m1(30) = -(15./56.)*tx(26) + (1./7.)*tx(25) -(1./sr42)*tax(13)
      t1m1(31) =  0.5*t1m1(29)
      t1m1(32) =  0.5*t1m1(30)
      t1m1(33) =  0.0
      t1m1(34) =  0.0
      t1m1(35) =  0.5 * ( -17./72.*t(32)  + 1./8.*t(31)
CCC  $                    - (1./sr56)*ta(7)  )
     $                    - (1./sr56)*ta(14)  )
      t1m1(36) =  0.5 * ( -17./72.*tx(32) + 1./8.*tx(31)
CCC  $                    - (1./sr56)*tax(7)  )
     $                    - (1./sr56)*tax(14)  )

      return
      end

